@@ -1,11 +1,12 @@
 /* -*- c++ -*-
 
 This is Picprog, Microchip PIC programmer software for the serial port device.
-Copyright © 1997,2002,2003,2004,2006,2008 Jaakko Hyvätti
+Copyright © 1997,2002,2003,2004,2006,2008,2010 Jaakko Hyvätti
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software Foundation,
-Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+along with this program.  If not, see http://www.gnu.org/licenses/ .
 
 The author may be contacted at:
 
@@ -23,20 +23,21 @@ URL:   http://www.iki.fi/hyvatti/
 Phone: +358 40 5011222
 
 Please send any suggestions, bug reports, success stories etc. to the
-Email address above.
+Email address above.  Include word 'picprog' in the subject line to
+make sure your email passes my spam filtering.
 
 */
 
 #include <iostream>
 #include <iomanip>
+#include <cstring>
+#include <cstdlib>
+#include <cctype>
+#include <cerrno>
+#include <csignal>
+#include <cassert>
 
 #include <sysexits.h>
-#include <string.h>
-#include <ctype.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <signal.h>
-#include <assert.h>
 #include <unistd.h>
 
 #include "hexfile.h"
@@ -475,7 +476,7 @@ hexfile::load (const char *name)
     while (i && isxdigit (buf [i]))
       i--;
 
-    if (i || ':' != buf [0] || 3 != (len & 3) || len < 15
+    if (i || ':' != buf [0] || 1 != (len & 1) || len < 13
 	|| '0' != buf [7] || '0' != buf [8]) {
       cerr << name << ':' << line << ":invalid input line." << endl
 	   << "Are you sure this is an 8 or 16 bit intel hex file?" << endl;
@@ -1162,6 +1163,23 @@ hexfile::program (picport &pic, bool reset, bool nopreserve)
     } else {
       // We are erasing the chip. Read OSCCAL and other reserved
       // words off the device first.
+
+      // Make sure we are in the program memory and below OSCCAL
+      // address
+      if (pic.address () > deviceinfo [dev].prog_size - deviceinfo [dev].prog_preserved) {
+	if (deviceinfo [dev].prog_bits == 12) {
+	  // 12f508/509 reset to configuration word.
+	  if (pic.address () != 0xfff)
+	    pic.reset (0xfff);
+	  // We need to step them to address 0.
+	  if (pic.address () == 0xfff && pic.address () > deviceinfo [dev].prog_size - deviceinfo [dev].prog_preserved)
+	    pic.command (picport::inc_addr, addr_max);
+	} else {
+	  if (pic.address ())
+	    pic.reset (0);
+	}
+      }
+
       for (;;) {
 	if (pic.address () >= deviceinfo [dev].prog_size - deviceinfo [dev].prog_preserved
 	    && pic.address () < deviceinfo [dev].prog_size) {
@@ -1347,6 +1365,7 @@ hexfile::program (picport &pic, bool reset, bool nopreserve)
 	  // Load data into the serial data holding register.
 	  pic.command18 (picport::instr, 0x50a8);
 	  pic.command18 (picport::instr, 0x6ef5);
+	  pic.command18 (picport::instr, 0x0000);
 	  int word = pic.command18 (picport::shift_out);
 	  if (word == data [addr])
 	    retval = NOT_PROGRAMMED;
@@ -1371,6 +1390,7 @@ hexfile::program (picport &pic, bool reset, bool nopreserve)
 	      }
 	      pic.command18 (picport::instr, 0x50a6);
 	      pic.command18 (picport::instr, 0x6ef5);
+	      pic.command18 (picport::instr, 0x0000);
 	      word = pic.command18 (picport::shift_out);
 	    } while (word & 2);
 	    // Disable writes.
@@ -1381,6 +1401,7 @@ hexfile::program (picport &pic, bool reset, bool nopreserve)
 	    // Load data into the serial data holding register.
 	    pic.command18 (picport::instr, 0x50a8);
 	    pic.command18 (picport::instr, 0x6ef5);
+	    pic.command18 (picport::instr, 0x0000);
 	    word = pic.command18 (picport::shift_out);
 	    if (word == data [addr])
 	      retval = EX_OK;
