@@ -1,11 +1,12 @@
 /* -*- c++ -*-
 
 This is Picprog, Microchip PIC programmer software for the serial port device.
-Copyright © 1997,2002,2003,2004,2006,2008 Jaakko Hyvätti
+Copyright © 1997,2002,2003,2004,2006,2008,2010 Jaakko Hyvätti
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software Foundation,
-Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+along with this program.  If not, see http://www.gnu.org/licenses/ .
 
 The author may be contacted at:
 
@@ -23,16 +23,18 @@ URL:   http://www.iki.fi/hyvatti/
 Phone: +358 40 5011222
 
 Please send any suggestions, bug reports, success stories etc. to the
-Email address above.
+Email address above.  Include word 'picprog' in the subject line to
+make sure your email passes my spam filtering.
 
 */
 
 #include <iostream>
+#include <cstring>
+#include <cstdlib>
 
 #include <sysexits.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <string.h>
 
 #include "hexfile.h"
 #include "program.h"
@@ -138,7 +140,7 @@ main (int argc, char **argv)
 
   if (!opt_quiet || opt_warranty || opt_copying || opt_usage)
     // Locale charset should be respected here.
-    cerr << "Picprog version 1.9.0, Copyright © 2008 Jaakko Hyvätti <Jaakko.Hyvatti@iki.fi>\n"
+    cerr << "Picprog version 1.9.1, Copyright © 2010 Jaakko Hyvätti <Jaakko.Hyvatti@iki.fi>\n"
       "Picprog comes with ABSOLUTELY NO WARRANTY; for details\n"
       "type `" << prog.name << " --warranty'.  This is free software,\n"
       "and you are welcome to redistribute it under certain conditions;\n"
