@@ -1,11 +1,12 @@
 /* -*- c++ -*-
 
 This is Picprog, Microchip PIC programmer software for the serial port device.
-Copyright © 1997,2002,2003,2004,2006,2007,2008 Jaakko Hyvätti
+Copyright © 1997,2002,2003,2004,2006,2007,2008,2010 Jaakko Hyvätti
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software Foundation,
-Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+along with this program.  If not, see http://www.gnu.org/licenses/ .
 
 The author may be contacted at:
 
@@ -23,7 +23,8 @@ URL:   http://www.iki.fi/hyvatti/
 Phone: +358 40 5011222
 
 Please send any suggestions, bug reports, success stories etc. to the
-Email address above.
+Email address above.  Include word 'picprog' in the subject line to
+make sure your email passes my spam filtering.
 
 */
 
@@ -31,18 +32,18 @@ Email address above.
 #include <fstream>
 #include <iomanip>
 #include <string>
+#include <cstring>
+#include <cstdlib>
+#include <cerrno>
+#include <ctime>
 
 #include <sys/ioctl.h>
 #include <sys/io.h>
 #include <fcntl.h>
-#include <errno.h>
-#include <time.h>
 #include <sys/time.h>
-#include <stdlib.h>
 #include <unistd.h>
 #include <termios.h>
 #include <sysexits.h>
-#include <string.h>
 #include <sched.h>
 
 #include "picport.h"
@@ -277,7 +278,7 @@ picport::picport (const char *tty, bool nordtsc, bool slow, bool reboot,
   set_clock_data (0, 0);
   set_vpp (1);
   // Charge Vdd
-  usleep (10000);
+  usleep (25000);
 
   // Detect delays that are needed for cable lenght
   bool successful_echo = false;
